OC.L10N.register(
    "files",
    {
    "Added to favorites" : "Adaugat la favorite",
    "Removed from favorites" : "Șters din favorite",
    "You added {file} to your favorites" : "Ai adaugat {file} în favorite",
    "You removed {file} from your favorites" : "Ai șters {file} din favorite",
    "Favorites" : "Favorite",
    "File changes" : "Modificări fișiere",
    "Created by {user}" : "Creat de {user}",
    "Changed by {user}" : "Modificat de {user}",
    "Deleted by {user}" : "Șters de {user}",
    "Restored by {user}" : "Restaurat de {user}",
    "Renamed by {user}" : "Redenumit de {user}",
    "Moved by {user}" : "Mutat de {user}",
    "You created {file}" : "Ai creat {file}",
    "You created an encrypted file in {file}" : "Ai creat un fișier criptat în {file}",
    "{user} created {file}" : "{user} a creat {file}",
    "{user} created an encrypted file in {file}" : "{user} a creat un fișier criptat în {file}",
    "{file} was created in a public folder" : "{file} a fost creat într-un director public ",
    "You changed {file}" : "Ai modificat {file}",
    "You changed an encrypted file in {file}" : "Ai modificat un fișier criptat în {file}",
    "{user} changed {file}" : "{user} a modificat {file}",
    "{user} changed an encrypted file in {file}" : "{user} a modificat un fișier criptat în {file}",
    "You deleted {file}" : "Ai șters {file}",
    "You deleted an encrypted file in {file}" : "Ai șters un fișier criptat în {file}",
    "{user} deleted {file}" : "{user} a șters {file}",
    "{user} deleted an encrypted file in {file}" : "{user} a șters un fișier criptat în {file}",
    "You restored {file}" : "Ai restaurat {file}",
    "{user} restored {file}" : "{user} a restaurat {file}",
    "You renamed {oldfile} (hidden) to {newfile} (hidden)" : "Ai redenumit {oldfile} (hidden) în {newfile} (hidden)",
    "You renamed {oldfile} (hidden) to {newfile}" : "Ai redenumit {oldfile} (hidden) în {newfile}",
    "You renamed {oldfile} to {newfile} (hidden)" : "Ai redenumit {oldfile} în {newfile} (ascuns)",
    "You renamed {oldfile} to {newfile}" : "Ai redenumit {oldfile} în {newfile}",
    "{user} renamed {oldfile} (hidden) to {newfile} (hidden)" : "{user} a redenumit {oldfile} (hidden) în {newfile} (hidden)",
    "{user} renamed {oldfile} (hidden) to {newfile}" : "{user} a redenumit {oldfile} (hidden) în {newfile}",
    "{user} renamed {oldfile} to {newfile} (hidden)" : "{user} a redenumit {oldfile} în {newfile} (hidden)",
    "{user} renamed {oldfile} to {newfile}" : "{user} a redenumit {oldfile} în {newfile}",
    "You moved {oldfile} to {newfile}" : "Ai mutat {oldfile} în {newfile}",
    "{user} moved {oldfile} to {newfile}" : "{user} a mutat {oldfile} în {newfile}",
    "A file has been added to or removed from your <strong>favorites</strong>" : "Un fișier a fost adăugat în sau șters din <strong>favorites</strong>",
    "Files" : "Fișiere",
    "A file or folder has been <strong>changed</strong>" : "Un nou fișier sau dosar a fost <strong>modificat</strong>",
    "A favorite file or folder has been <strong>changed</strong>" : "Un fișier sau dosar favorit a fost <strong>schimbat</strong>",
    "No favorites" : "Fără favorite",
    "Accept" : "Accept",
    "Reject" : "Respinge",
    "Incoming ownership transfer from {user}" : "Se transferă proprietatea de la {user}",
    "Do you want to accept {path}?\n\nNote: The transfer process after accepting may take up to 1 hour." : "Dorești să accepți  {path}?\n\nNotă: Procesul de transfer după acceptare poate să durește până la 1 oră.",
    "Ownership transfer failed" : "Transferul de proprietate a eșuat",
    "Your ownership transfer of {path} to {user} failed." : "Transferul tău de proprietate de {path} către {user} a eșuat.",
    "The ownership transfer of {path} from {user} failed." : "Transferul de proprietate de {path} către {user} a eșuat.",
    "Ownership transfer done" : "Transferul de proprietate s-a finalizat",
    "Your ownership transfer of {path} to {user} has completed." : "Transferul tău de proprietate de {path} către {user} s-a finalizat.",
    "The ownership transfer of {path} from {user} has completed." : "Transferul de proprietate de {path} către {user} s-a finalizat.",
    "in %s" : "în %s",
    "File Management" : "Management fișiere",
    "Home" : "Acasă",
    "Target folder does not exist any more" : "Directorul destinație nu mai există",
    "Reload current directory" : "Reîncarcă directorul curent",
    "Go to the \"{dir}\" directory" : "Salt la directorul \"{dir}\" ",
    "Drag and drop files here to upload" : "Faceți Drag and drop cu fișierele aici pentru upload",
    "Favorite" : "Favorit",
    "Back" : "Înapoi",
    "Filename" : "Nume fișier",
    "Folder name" : "Denumire director",
    "This node is unavailable" : "Acest nod este indisponibil",
    "Renamed \"{oldName}\" to \"{newName}\"" : "A fost redenumit  \"{oldName}\" cu \"{newName}\"",
    "Rename file" : "Redenumire fișier",
    "Folder" : "Director",
    "Pending" : "În așteptare",
    "Clear filter" : "Șterge filtrul",
    "Modified" : "Modificat",
    "Type" : "Tip",
    "Active filters" : "Filtre active",
    "Total rows summary" : "Rezumat total rânduri",
    "Name" : "Nume",
    "Size" : "Mărime",
    "\"{displayName}\" batch action executed successfully" : "\"{displayName}\" acțiunea batch a fost executată cu succes",
    "\"{displayName}\" action failed" : "Acțiunea \"{displayName}\" a eșuat",
    "Actions" : "Acțiuni",
    "List of files and folders." : "Listă fișiere și foldere",
    "This list is not fully rendered for performance reasons. The files will be rendered as you navigate through the list." : "Această lista este incomplet afișată din motive de performanță. Fișierele vor fi afișate pe măsură ce navigați prin listă.",
    "File not found" : "Fișierul nu a fost găsit",
    "{usedQuotaByte} used" : "{usedQuotaByte} utilizați",
    "{used} of {quota} used" : "{used} din {quota} folosiți",
    "{relative}% used" : "{relative}% utilizat",
    "Could not refresh storage stats" : "Nu pot actualiza statisticile de stocare",
    "Your storage is full, files can not be updated or synced anymore!" : "Spațiul de stocare este plin, fișierele nu mai pot fi actualizate sau sincronizate!",
    "New folder" : "Un nou dosar",
    "Create new folder" : "Creează director nou",
    "Create" : "Crează",
    "Submit" : "Trimite",
    "Choose a file or folder to transfer" : "Alege un fișier sau dosar de transferat",
    "Transfer" : "Transfer",
    "Transfer {path} to {userid}" : "Transferă {path} către {userid}",
    "Invalid path selected" : "Calea selectată este invalidă",
    "Unknown error" : "Eroare necunoscută",
    "Ownership transfer request sent" : "Cererea de transfer a fost trimisă",
    "Cannot transfer ownership of a file or folder you do not own" : "Nu se poate transfera proprietatea unui fișier sau dosar daca nu le deții",
    "Transfer ownership of a file or folder" : "Transferă proprietatea unui fisier sau dosar",
    "Choose file or folder to transfer" : "Alege fișierul sau dosarul de transferat",
    "Change" : "Modificare",
    "New owner" : "Proprietarul nou",
    "Select file or folder to link to" : "Selectați fișierul sau folderul țintă a link-ului",
    "Choose {file}" : "Selectați {file}",
    "Share" : "Partajează",
    "Shared by link" : "Partajat prin link",
    "Shared" : "Partajat",
    "Switch to list view" : "Comuta la organizarea tip listă",
    "Switch to grid view" : "Comută la organizare tip grilă",
    "Not enough free space" : "Spațiu insuficient",
    "Operation is blocked by access control" : "Operația este blocată de către controlul de acces",
    "\"{displayName}\" action executed successfully" : "Acțiunea \"{displayName}\" a fost executată cu succes",
    "Loading current folder" : "Se încarcă folderul curent",
    "Retry" : "Reîncearcă",
    "No files in here" : "Niciun fișier aici",
    "Upload some content or sync with your devices!" : "Încarcă ceva conținut sau sincronizează cu dispozitivele tale!",
    "Go back" : "Înapoi",
    "Views" : "Mod de viziualizare",
    "Files settings" : "Setări Fișiere",
    "File cannot be accessed" : "Fișierul nu poate fi accesat",
    "Clipboard is not available" : "Clipboardul este indisponibil",
    "WebDAV URL copied to clipboard" : "URL-ul WebDAV a fost copiat în clipboard",
    "Sort favorites first" : "Sortați favoritele primele",
    "Show hidden files" : "Arată fișierele ascunse",
    "Crop image previews" : "Previzualizarea imaginii decupate",
    "Enable the grid view" : "Activați organizarea tip grilă",
    "Additional settings" : "Setări adiționale",
    "WebDAV" : "WebDAV",
    "Copy to clipboard" : "Copiază în clipboard",
    "Use this address to access your Files via WebDAV" : "Folosiți această adresă pentru a accesa fișierele dumneavoastră folosind WebDAV",
    "If you have enabled 2FA, you must create and use a new app password by clicking here." : "Dacă ați activat 2FA, trebuie să creați și să folosiți o nouă parolă de aplicație, dând click aici.",
    "Keyboard shortcuts" : "Scurtături din tastatură",
    "Navigation" : "Navigare",
    "View" : "Vizualizare",
    "You" : "Tu",
    "Error while loading the file data" : "A apărut o eroare în timpul încărcării datele din fișier",
    "Owner" : "Proprietar",
    "Remove from favorites" : "Șterge din favorite",
    "Add to favorites" : "Adaugă la favorite",
    "Tags" : "Etichete",
    "Blank" : "Gol",
    "Unable to create new file from template" : "Nu s-a putut creea un fisier nou pentru acest șablon",
    "Pick a template for {name}" : "Alege un șablon pentru {name}",
    "Create a new file with the selected template" : "Crează un fișier nou cu șablonul selectat",
    "Creating file" : "Se crează fișierul",
    "Disconnect storage" : "Deconectează stocarea",
    "Delete permanently" : "Șterge permanent",
    "Delete" : "Șterge",
    "Cancel" : "Anulare",
    "You cannot move a file/folder onto itself or into a subfolder of itself" : "Nu se poate muta/redenumi un fișier/folder în el însuși sau într-un subfolder al său",
    "A file or folder with that name already exists in this folder" : "Un fișier sau folder cu acest nume există deja în acest folder",
    "The file does not exist anymore" : "Fișierul nu mai există",
    "Copy to {target}" : "Copiază la {target}",
    "Copy" : "Copiază",
    "Move to {target}" : "Mută la {target}",
    "Move" : "Mută",
    "Move or copy" : "Mută sau copiază",
    "Cancelled move or copy operation" : "Copierea sau mutarea a fost anulată",
    "Open folder {displayName}" : "Deschide dosarul {displayName}",
    "Open in Files" : "Deschide în Fișiere",
    "Failed to redirect to client" : "Eroare la redirectarea către client",
    "Rename" : "Redenumește",
    "Open details" : "Deschide detaliile",
    "View in folder" : "Vizualizează în director",
    "Today" : "Azi",
    "Last 7 days" : "Ultimele 7 zile",
    "Last 30 days" : "Ultimele 30 de zile",
    "Documents" : "Documente",
    "Audio" : "Audio",
    "Videos" : "Fișiere video",
    "Created new folder \"{name}\"" : "A fost creat folderul nou \"{name}\"",
    "Unable to initialize the templates directory" : "Nu s-a putut inițializa dosarul cu șabloane",
    "Templates" : "Șabloane",
    "Some files could not be moved" : "Unele fișiere nu au putut fi mutate",
    "This operation is forbidden" : "Operațiunea este interzisă",
    "This directory is unavailable, please check the logs or contact the administrator" : "Acest director nu este disponibil, te rugăm verifică logurile sau contactează un administrator",
    "Storage is temporarily not available" : "Spațiu de stocare este indisponibil temporar",
    "_%n file_::_%n files_" : ["%n fișier","%n fișiere","%n fișiere"],
    "_%n folder_::_%n folders_" : ["%n director","%n directoare","%n directoare"],
    "No favorites yet" : "Nu aveți favorite încă",
    "Files and folders you mark as favorite will show up here" : "FIșierele și directoarele pe care le marchezi ca favorite vor apărea aici",
    "All files" : "Toate fișierele",
    "List of your files and folders." : "Lista fișierelor și dosarelor personale.",
    "Personal files" : "Fișiere personale",
    "Recent" : "Recente",
    "List of recently modified files and folders." : "Lista fișierelor și dosarelor modificate recent.",
    "No recently modified files" : "Niciun fișier modificat recent",
    "Files and folders you recently modified will show up here." : "Fișierele și dosarele modificate recent vor fi afișate aici",
    "No entries found in this folder" : "Niciun element găsit în acest director",
    "Select all" : "Selectează tot",
    "Upload too large" : "Fișierul încărcat este prea mare",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Fișierele pe care încerci să le încarci depășesc limita de încărcare maximă admisă pe acest server.",
    "File could not be found" : "Fișierul nu a fost găsit",
    "Download" : "Descarcă",
    "Show list view" : "Afișează vizualizarea listă",
    "Show grid view" : "Afișează vizualizarea grilă",
    "Close" : "Închide",
    "Could not create folder \"{dir}\"" : "Nu s-a putut crea directorul \"{dir}\"",
    "This will stop your current uploads." : "Asta va opri descărcările curente.",
    "Upload cancelled." : "Încărcare anulată.",
    "Processing files …" : "Procesare fișiere ...",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "Nu se poate încărca {filename} deoarece este un director sau are mărimea de 0 octeți",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "Spațiu liber insuficient, încărcați {size1} însă doar {size2} disponibil rămas",
    "Target folder \"{dir}\" does not exist any more" : "Directorul \"{dir}\" nu mai există",
    "An unknown error has occurred" : "A apărut o eroare necunoscută!",
    "File could not be uploaded" : "Fișierele nu au putut fi încărcate",
    "Uploading …" : "Încărcare...",
    "Uploading … ({currentNumber}/{total})" : "Se încarcă … ({currentNumber}/{total})",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} din {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "Încărcarea acestui obiect nu este suportată",
    "Error when assembling chunks, status code {status}" : "Eroare la asambralea bucăților, status cod {status}",
    "Choose target folder" : "Alege directorul destinație",
    "Set reminder" : "Setează memo",
    "Edit locally" : "Editează local",
    "Open" : "Deschide",
    "Could not load info for file \"{file}\"" : "Nu s-a putut încărca informația pentru fișierul \"{file}\"",
    "Details" : "Detalii",
    "Please select tag(s) to add to the selection" : "Selectați eticheta(ele) pentru adăugare la selecție",
    "Apply tag(s) to selection" : "Aplică eticheta(ele) selecției",
    "Select directory \"{dirName}\"" : "Selectează dosarul \"{dirName}\"",
    "Select file \"{fileName}\"" : "Selectează fișierul \"{fileName}\"",
    "Unable to determine date" : "Nu s-a putut determina data",
    "Could not move \"{file}\", target exists" : "Nu s-a putut muta fișierul \"{file}\", există deja un altul cu același nume în directorul destinație",
    "Could not move \"{file}\"" : "Nu s-a putut muta fișierul \"{file}\"",
    "copy" : "copiază",
    "Could not copy \"{file}\", target exists" : "Nu s-a putut copia \"{file}\", există deja un altul cu același nume în directorul destinație",
    "Could not copy \"{file}\"" : "Nu s-a putut copia \"{file}\"",
    "Copied {origin} inside {destination}" : "S-a copiat {origin} în {destination}",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "S-a copiat {origin} și {nbfiles} alte fișiere în {destination}",
    "{newName} already exists" : "{newName} există deja",
    "Could not rename \"{fileName}\", it does not exist any more" : "Nu s-a putut redenumi \"{fileName}\", fișierul nu mai există",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Numele \"{targetName}\" este deja folosit în directorul \"{dir}\". Alege un nume diferit.",
    "Could not rename \"{fileName}\"" : "Nu s-a putut redenumi \"{fileName}\"",
    "Could not create file \"{file}\"" : "Nu s-a putut crea fișierul \"{file}\"",
    "Could not create file \"{file}\" because it already exists" : "Nu s-a putut crea fișierul \"{file}\" deoarece există deja unul cu același nume",
    "Could not create folder \"{dir}\" because it already exists" : "Nu s-a putut crea directorul \"{dir}\" deoarece există deja unul cu același nume",
    "Could not fetch file details \"{file}\"" : "Nu s-au putut aduna detalii \"{file}\"",
    "Error deleting file \"{fileName}\"." : "Eroare la ștergerea fișierului \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "Nu au fost găsite rezultate în alte directoare pentru {tag}{filter}{endtag}",
    "Enter more than two characters to search in other folders" : "Introduceți mai mult de două caractere pentru a căuta în alte dosare",
    "{dirs} and {files}" : "{dirs} și {files}",
    "_including %n hidden_::_including %n hidden_" : ["incluzând %n ascuns","incluzând %nascunse","incluzând %nascuns"],
    "You do not have permission to upload or create files here" : "Nu ai permisiunea de a încărca fișiere aici",
    "_Uploading %n file_::_Uploading %n files_" : ["Se încarcă %n fișier.","Se încarcă %n fișiere.","Se încarcă %n fișiere."],
    "New" : "Nou",
    "New file/folder menu" : "Meniu Fișier/Folder nou",
    "Select file range" : "Selectează un interval",
    "{used} used" : "{used} folosiți",
    "\"{name}\" is an invalid file name." : "\"{name}\" este un nume de fișier nevalid.",
    "File name cannot be empty." : "Numele fișierului nu poate rămâne gol.",
    "\"/\" is not allowed inside a file name." : "\"/\" nu este permis în denumirea fișierului.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" ",
    "Storage of {owner} is full, files cannot be updated or synced anymore!" : "Spațiul de stocare alocat {owner} este plin, drept urmare fișierele nu mai pot fi sincronizate sau updatate !",
    "Group folder \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Dosarul \"{mountPoint}\" este plin, fisiere nu mai pot fi reîmprospătate sau sincronizate!",
    "External storage \"{mountPoint}\" is full, files cannot be updated or synced anymore!" : "Stocarea externă \"{mountPoint}\" este plina, fisierele nu mai pot fi reîmprospătate sau sincronizate!",
    "Your storage is full, files cannot be updated or synced anymore!" : "Dosarul tău este plin, fisiere nu mai pot fi reîmprospătate sau sincronizate!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)." : "Stocarea lui {owner} este aproape plină în proporție de ({usedSpacePercent}%).",
    "Group folder \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Dosarul \"{mountPoint}\" este aproape plin in proporție de ({usedSpacePercent}%).",
    "External storage \"{mountPoint}\" is almost full ({usedSpacePercent}%)." : "Stocarea externă \"{mountPoint}\" este aproape plină in proporție de ({usedSpacePercent}%).",
    "Your storage is almost full ({usedSpacePercent}%)." : "Stocarea dumneavoastra este aproape plină în proporție de  ({usedSpacePercent}%).",
    "_matches \"{filter}\"_::_match \"{filter}\"_" : ["potrivește \"{filter}\"","potrivește \"{filter}\"","potrivește \"{filter}\""],
    "Path" : "Cale",
    "_%n byte_::_%n bytes_" : ["%n octet","%n octeți","%n octeți"],
    "Upload file" : "Încarcă fișier",
    "An error occurred while trying to update the tags" : "A apărut o eroare în timpul actualizării etichetelor",
    "Upload (max. %s)" : "Încarcă (max. %s)",
    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} folder","{folderCount} foldere","{folderCount} foldere"],
    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} fișier","{fileCount} fișiere","{fileCount} fișiere"],
    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["1 fișier și {folderCount} folder","1 fișier și {folderCount} foldere","1 fișier și {folderCount} foldere"],
    "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} fișier și 1 folder","{fileCount} fișiere și 1 folder","{fileCount} fișiere și 1 folder"],
    "{fileCount} files and {folderCount} folders" : "{fileCount} fișiere și {folderCount} dosare",
    "Text file" : "Fișier text",
    "New text file.txt" : "Fișier nou.txt"
},
"nplurals=3; plural=(n==1?0:(((n%100>19)||((n%100==0)&&(n!=0)))?2:1));");
